﻿<?php
/**
 * Этот компонент предназначен для создания ссылок с помощью
 * сервиса Bit.ly
 */
class BitLyShortener extends CComponent {
    const LOGIN = 'ваш_логин';
    const APIKEY = 'ваш_API_ключ';
    
    /**
     * Укорачивает заданнй URL с помощью сервиса Bit.ly
     *
     * @param $fullUrl string - URL для которого нужно получить короткую ссылку
     * @return string короткая ссылка
     */
    public static function getShortUrl($fullUrl) {
        //формируем запрос
        $request = 'http://api.bit.ly/v3/shorten?'
            .'login='.self::LOGIN
            .'&apiKey='.self::APIKEY
            .'&longUrl='.urlencode($fullUrl)
            .'&format=json';
        
        //отправляем запрос
        $response = file_get_contents($request);
        $res = json_decode($response, true);
        
        return $res['data']['url'];
    }
    
    /**
     * Определяет количество переходов по коротким ссылкам.
     *
     * @param array $models массив с моделями
     * @return добавляет данные в исходный массив
     */
    public static function getStatistics(&$models) {
        //если массив пуст - не делаем ничего
        if (0 == count($models)) {
            return;
        }
        /*
         В запросе к Bit.ly можно передать до 15 ссылок.
         Поэтому сначала формируем общую часть запроса, а
         затем - добавляем в цикле ссылки, для которых
         нужно получить статистику.
        */
        $requestBase = 'http://api.bit.ly/v3/clicks?'
            .'login='.self::LOGIN
            .'&apiKey='.self::APIKEY
            .'&format=json';
        
        //разбиваем массив с моделями на блоки по 15 элементов
        $modelsChunks = array_chunk($models, 15, true);
        //для каждого блока формируем и отправляем запрос
        foreach ($modelsChunks as $i => $chunk) {
            $request = $requestBase;
            foreach ($chunk as $key => $model) {
                $request .= '&shortUrl='.urlencode($model->n_short_url);
            }
            $response = file_get_contents($request);
            $res = json_decode($response, true);
            //сохраняем результаты
            foreach ($chunk as $key => $model) {
                $models[$key]->n_clicks = $res['data']['clicks'][$key - $i*15]['global_clicks'];
            }
        }
    }
}

//end of BitLyshortener.php